/* ************************************************************************** */
/** Descriptive File Name

  @Company
    Company Name

  @File Name
    filename.c

  @Summary
    Brief description of the file.

  @Description
    Describe the purpose of this file.
 */
/* ************************************************************************** */

/* ************************************************************************** */
/* ************************************************************************** */
/* Section: Included Files                                                    */
/* ************************************************************************** */
/* ************************************************************************** */

#include <stdint.h>
#include <stdbool.h>

#include "driver/i2c/drv_i2c_static.h"
#include "oled.h"
#include "font.h"


/* ************************************************************************** */
/* ************************************************************************** */
/* Section: File Scope or Global Data                                         */
/* ************************************************************************** */
/* ************************************************************************** */

/*  A brief description of a section can be given directly below the section
    banner.
 */

/* ************************************************************************** */
/** Descriptive Data Item Name

  @Summary
    Brief one-line summary of the data item.
    
  @Description
    Full description, explaining the purpose and usage of data item.
    <p>
    Additional description in consecutive paragraphs separated by HTML 
    paragraph breaks, as necessary.
    <p>
    Type "JavaDoc" in the "How Do I?" IDE toolbar for more information on tags.
    
  @Remarks
    Any additional remarks
 */

uint8_t oledBuffer[OLED_SIZE];


/* ************************************************************************** */
/* ************************************************************************** */
// Section: Local Functions                                                   */
/* ************************************************************************** */
/* ************************************************************************** */

/*  A brief description of a section can be given directly below the section
    banner.
 */

/* ************************************************************************** */

/** 
  @Function
    int ExampleLocalFunctionName ( int param1, int param2 ) 

  @Summary
    Brief one-line description of the function.

  @Description
    Full description, explaining the purpose and usage of the function.
    <p>
    Additional description in consecutive paragraphs separated by HTML 
    paragraph breaks, as necessary.
    <p>
    Type "JavaDoc" in the "How Do I?" IDE toolbar for more information on tags.

  @Precondition
    List and describe any required preconditions. If there are no preconditions,
    enter "None."

  @Parameters
    @param param1 Describe the first parameter to the function.
    
    @param param2 Describe the second parameter to the function.

  @Returns
    List (if feasible) and describe the return values of the function.
    <ul>
      <li>1   Indicates an error occurred
      <li>0   Indicates an error did not occur
    </ul>

  @Remarks
    Describe any special behavior not described above.
    <p>
    Any additional remarks.

  @Example
    @code
    if(ExampleFunctionName(1, 2) == 0)
    {
        return 3;
    }
 */
static int ExampleLocalFunction(int param1, int param2)
{
    return 0;
}

static void _i2cWrite(uint8_t reg, uint8_t *data, uint32_t size)
{
    uint8_t *send = data;
    
    while(DRV_I2C0_MasterBusIdle() == false);
    DRV_I2C0_MasterStart();
    DRV_I2C0_WaitForStartComplete();

    /* Send ADDRESS */
    while(DRV_I2C0_MasterBusIdle() == false);
    DRV_I2C0_ByteWrite(OLED_ADDRESS << 1);
    while(DRV_I2C0_WaitForByteWriteToComplete() == false);
    while(DRV_I2C0_WaitForACKOrNACKComplete() == false);
    if(DRV_I2C0_WriteByteAcknowledged())
    {
        /* Send REGISTER */
        while(DRV_I2C0_MasterBusIdle() == false);
        DRV_I2C0_ByteWrite(reg);
        while(DRV_I2C0_WaitForByteWriteToComplete() == false);
        while(DRV_I2C0_WaitForACKOrNACKComplete() == false);
        if(DRV_I2C0_WriteByteAcknowledged())
        {
            while(size--)
            {
                /* Send DATA */
                while(DRV_I2C0_MasterBusIdle() == false);
                DRV_I2C0_ByteWrite(*send);
                while(DRV_I2C0_WaitForByteWriteToComplete() == false);
                while(DRV_I2C0_WaitForACKOrNACKComplete() == false);
                if(DRV_I2C0_WriteByteAcknowledged())
                {
                    send++;
                }
                else
                {
                    break;
                }
            }
        }
    }   

    /* Send STOP */
    while(DRV_I2C0_MasterBusIdle() == false);
    DRV_I2C0_MasterStop();
    DRV_I2C0_WaitForStopComplete();
}

static void _sendCommand(uint8_t *data, uint32_t size)
{
    _i2cWrite(0x00, data, size);
}

static void _sendData(uint8_t *data, uint32_t size)
{
    _i2cWrite(0x40, data, size);
}

static void _set_display_on_off(bool state)
{
    uint8_t command[1] = { 0xae | (uint8_t)state };
    _sendCommand(command, sizeof(command));
}

static void _set_multiplex_ratio(uint8_t ratio)
{
    uint8_t command[2] = { 0xa8, ratio };
    _sendCommand(command, sizeof(command));
}

static void _set_display_offset(uint8_t offset)
{
    uint8_t command[2] = { 0xd3, offset };
    _sendCommand(command, sizeof(command));
}

static void _set_display_start_line(uint8_t line)
{
    uint8_t command[1] = { 0x40 | line };
    _sendCommand(command, sizeof(command));
}

static void _set_segment_remap(uint8_t remap)
{
    uint8_t command[1] = { 0xa0 | remap };
    _sendCommand(command, sizeof(command));
}

static void _set_com_scan_direction(uint8_t dir)
{
    uint8_t command[1] = { 0xc0 | dir << 3 };
    _sendCommand(command, sizeof(command));
}

static void _set_com_pins_configuration(uint8_t conf, uint8_t remap)
{
    uint8_t command[2] = { 0xda, 0x02 | (conf << 4) | (remap << 5) };
    _sendCommand(command, sizeof(command));
}

static void _set_contrast_control(uint8_t contrast)
{
    uint8_t command[2] = { 0x81, contrast };
    _sendCommand(command, sizeof(command));
}


static void _entire_display_on(uint8_t status)
{
    uint8_t command[1] = { 0xa4 | status };
    _sendCommand(command, sizeof(command));
}

static void _set_inverse_display(uint8_t inverse)
{
    uint8_t command[1] = { 0xa6 | inverse };
    _sendCommand(command, sizeof(command));
}

static void _set_display_clock(uint8_t divider, uint8_t freq)
{
    uint8_t command[2] = { 0xd5, (freq << 4 | divider) };
    _sendCommand(command, sizeof(command));
}

static void _charge_pump_settings(uint8_t on)
{
    uint8_t command[2] = { 0x8d, 0x10 | (on << 2) };
    _sendCommand(command, sizeof(command));
}

static void _set_memory_addressing_mode(uint8_t mode)
{
    uint8_t command[2] = { 0x20, mode };
    _sendCommand(command, sizeof(command));
}

static void _set_column_address(uint8_t start, uint8_t end)
{
    uint8_t command[3] = { 0x21, start, end };
    _sendCommand(command, sizeof(command));
}

static void _set_page_address(uint8_t start, uint8_t end)
{
    uint8_t command[3] = { 0x22, start, end };
    _sendCommand(command, sizeof(command));
}

static inline _swap(uint8_t *a, uint8_t *b)
{
    uint8_t x;
    x = *a;
    *a = *b;
    *b = x;
}

/* ************************************************************************** */
/* ************************************************************************** */
// Section: Interface Functions                                               */
/* ************************************************************************** */
/* ************************************************************************** */

/*  A brief description of a section can be given directly below the section
    banner.
 */

// *****************************************************************************

/** 
  @Function
    int ExampleInterfaceFunctionName ( int param1, int param2 ) 

  @Summary
    Brief one-line description of the function.

  @Remarks
    Refer to the example_file.h interface header for function usage details.
 */
void oledInitialize(void)
{    
    BSP_LCDTurnOn();
    /* Send initialization */
    _set_display_on_off(false);
    _set_multiplex_ratio(63);
    _set_display_offset(0);
    _set_display_start_line(0);
    
    _set_segment_remap(1);
        
    _set_com_pins_configuration(1, 0);
    _set_com_scan_direction(1);
    
    
    _set_contrast_control(0x7f);
    _entire_display_on(0);
    _set_inverse_display(0);
    _set_display_clock(0, 15);
    _charge_pump_settings(1);
    _set_display_on_off(true);
    
    _set_memory_addressing_mode(0);
    _set_column_address(0, 127);
    _set_page_address(0, 7);
    
    /* Clear display */
    oledClear();
    oledUpdate();
}

void oledUpdate(void)
{
    _sendData(oledBuffer, OLED_SIZE);
}


void oledClear(void)
{
    memset(oledBuffer, 0, OLED_SIZE);
}

void oledDrawPixel(uint8_t Row, uint8_t Column, uint8_t Color)
{
    if(Row < 0 || Row >= HEIGHT || Column < 0 || Column >= WIDTH)
        return;
    if (Color)
        oledBuffer[Row/8 * 128 + Column] |= 1 << (Row % 8);
    else
        oledBuffer[Row/8 * 128 + Column] &= ~(1 << (Row % 8));
}


void oledDrawVLine(uint8_t Row)
{
    uint8_t i;
    for(i = 0; i < HEIGHT; i++)
    {
        oledDrawPixel(i, Row, WHITE);
    }
}

void oledDrawHLine(uint8_t Column)
{
    uint8_t i;
    for(i = 0; i < WIDTH; i++)
    {
        oledDrawPixel(Column, i, WHITE);
    }
}

void oledDrawPixelChar(uint8_t Row, uint8_t Column, uint8_t Color)
{
    if(Row < 0 || Row >= HEIGHT || Column < 0 || Column >= WIDTH)
        return;
#if 0
    if (Color)
        oledBuffer[Row/8 * 128 + Column] |= 1 << (Row % 8);
    else
        oledBuffer[Row/8 * 128 + Column] &= ~(1 << (Row % 8));
#else   // same idea but using bitwise operations (they are faster)
    if (Color)
        oledBuffer[((Row>>3)<<7) + Column] |= 1 << (Row & 7);
    else
        oledBuffer[((Row>>3)<<7) + Column] &= ~(1 << (Row & 7));
#endif
    return;
}

// works only if the Row is divided by 8
void oledDrawPixelChar2(uint8_t Row, uint8_t Column, uint8_t Data)
{
    if(Row < 0 || Row >= HEIGHT || Column < 0 || Column >= WIDTH)
        return;
    oledBuffer[((Row>>3)<<7) + Column] = Data;
    return;
}

void oledClearRow (uint8_t Row, uint8_t Inverse)
{
    uint8_t i;
    if (Inverse)
        for (i=0; i<128; i++)
            oledDrawPixelChar2 (Row<<3, i, 0xFF);
    else
        for (i=0; i<128; i++)
            oledDrawPixelChar2 (Row<<3, i, 0);
}

void oledDrawChar (uint8_t StartRow, uint8_t StartColumn, uint8_t C, uint8_t Inverse)
{
    unsigned char Row, Column, Temp;
    for (Column=0; Column<6; Column++)
    {
        if (Column==5)
            Temp = 0;
        else
            Temp = font_6x8 [C-32][Column];
        if (Inverse)
            Temp = ~Temp;
        for (Row=0; Row<8; Row++)
            oledDrawPixelChar(StartRow+Row, StartColumn+Column, Temp & (1<<Row));
            //oledDrawPixelChar2(StartRow+Row, StartColumn+Column, Temp);
    }       
    return;
}

void oledDrawString (uint8_t x, uint8_t y, uint8_t C[], uint8_t Inverse)
{
    int i;
    for (i=0; C[i]; i++)
        oledDrawChar (x, y+i*6, C[i], Inverse);
    return;
}

/* *****************************************************************************
 End of File
 */
