/*******************************************************************************
  ADC Driver Initialization File

  File Name:
    drv_adc_static.c

  Summary:
    This file contains source code necessary to initialize the ADC driver.

  Description:
    This file contains source code necessary to initialize the system.  It
    implements the "DRV_ADC_Initialize" function, configuration bits, and allocates
    any necessary global system resources, such as the systemObjects structure
    that contains the object handles to all the MPLAB Harmony module objects in
    the system.
 *******************************************************************************/

/*******************************************************************************
Copyright (c) 2013-2014 released Microchip Technology Inc.  All rights reserved.

Microchip licenses to you the right to use, modify, copy and distribute
Software only when embedded on a Microchip microcontroller or digital signal
controller that is integrated into your product or third party product
(pursuant to the sublicense terms in the accompanying license agreement).

You should refer to the license agreement accompanying this Software for
additional information regarding your rights and obligations.

SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND,
EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER
CONTRACT, NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR
OTHER LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR
CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF
SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
(INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.
 *******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Include Files
// *****************************************************************************
// *****************************************************************************
#include "framework/driver/adc/drv_adc_static.h"
 
<#if CONFIG_USE_DRV_ADC == true>
<#if CONFIG_DRV_ADC_DRIVER_MODE == "STATIC">
// *****************************************************************************
// *****************************************************************************
// Section: ADC Static Driver Functions
// *****************************************************************************
// *****************************************************************************
void DRV_ADC_Initialize(void)
{
    /* Select Clock Source */
    PLIB_ADC_ConversionClockSourceSelect(DRV_ADC_ID_1, ${CONFIG_DRV_ADC_CLK_SOURCE_SELECT});
    /* Select Clock Prescaler */
<#if CONFIG_DRV_ADC_CLK_SOURCE_SELECT == "ADC_CLOCK_SOURCE_SYSTEM_CLOCK">	
    PLIB_ADC_ConversionClockSet(DRV_ADC_ID_1, SYS_CLK_FREQ, ${CONFIG_DRV_ADC_CLK_VALUE_SELECT});
<#else>
    PLIB_ADC_ConversionClockSet(DRV_ADC_ID_1, SYS_CLK_CONFIG_PRIMARY_XTAL, ${CONFIG_DRV_ADC_CLK_VALUE_SELECT});
</#if>

    /* Select Power Mode */
<#if CONFIG_DRV_ADC_POWER_STATE == "SYS_MODULE_POWER_IDLE_STOP">
    PLIB_ADC_StopInIdleEnable(DRV_ADC_ID_1);
<#else>
    PLIB_ADC_StopInIdleDisable(DRV_ADC_ID_1);
</#if>
<#if CONFIG_DRV_ADC_OFFSET_CALIBRATION == true>

    /* Enable Calibration */
    PLIB_ADC_CalibrationEnable(DRV_ADC_ID_1);
</#if>
	
    /* Select Voltage Reference */
<#if CONFIG_DRV_ADC_VOLTAGE_REFERENCE_ADC?has_content>	
    PLIB_ADC_VoltageReferenceSelect(DRV_ADC_ID_1, ${CONFIG_DRV_ADC_VOLTAGE_REFERENCE_ADC});
</#if>

    /* Sampling Selections */
<#if CONFIG_DRV_ADC_AUTO_SAMPLE_EN ==true>
    /* Enable Auto Sample Mode */
    PLIB_ADC_SampleAutoStartEnable(DRV_ADC_ID_1);
<#if CONFIG_DRV_ADC_ACQUISITION_TIME?has_content>	
    /* Sample Acquisition Time (Auto Sample Mode) */	
    PLIB_ADC_SampleAcquisitionTimeSet(DRV_ADC_ID_1, ${CONFIG_DRV_ADC_ACQUISITION_TIME});
</#if>
<#if CONFIG_DRV_ADC_STOP_CONVERSION == true>
    /* Stop Conversion Sequence on First Interrupt (Auto Sample Mode) */
    PLIB_ADC_ConversionStopSequenceEnable(DRV_ADC_ID_1);
</#if>
</#if>
<#if CONFIG_DRV_ADC_ALTS_MODE?has_content>
    /* Select Sampling Mode */
    PLIB_ADC_SamplingModeSelect(DRV_ADC_ID_1, ${CONFIG_DRV_ADC_ALTS_MODE});
</#if>
<#if CONFIG_DRV_ADC_NUMBER_OF_SAMPLES?has_content>
    /* Number of Samples Per Interrupt */
    PLIB_ADC_SamplesPerInterruptSelect(DRV_ADC_ID_1, ${CONFIG_DRV_ADC_NUMBER_OF_SAMPLES});
</#if>

    /* Conversion Selections */
<#if CONFIG_DRV_ADC_TRIG_SRC?has_content>
    /* Select Trigger Source */
    PLIB_ADC_ConversionTriggerSourceSelect(DRV_ADC_ID_1, ${CONFIG_DRV_ADC_TRIG_SRC});
</#if>
<#if CONFIG_DRV_ADC_OUTPUT_FOMRAT?has_content>
    /* Select Result Format */
    PLIB_ADC_ResultFormatSelect(DRV_ADC_ID_1, ${CONFIG_DRV_ADC_OUTPUT_FOMRAT});
</#if>
<#if CONFIG_DRV_ADC_BUFFER_RESULT_MODE?has_content>
    /* Buffer Mode */
    PLIB_ADC_ResultBufferModeSelect(DRV_ADC_ID_1, ${CONFIG_DRV_ADC_BUFFER_RESULT_MODE});
</#if>

    /* Channel Selections */
<#if CONFIG_DRV_ADC_ALTS_MODE == "ADC_SAMPLING_MODE_MUXA">
<#if CONFIG_DRV_ADC_MUXA_NEG_INPUT?has_content>
    /* MUX A Negative Input Select */
    PLIB_ADC_MuxChannel0InputNegativeSelect(DRV_ADC_ID_1, ADC_MUX_A, ${CONFIG_DRV_ADC_MUXA_NEG_INPUT});
</#if>
<#else>
<#if CONFIG_DRV_ADC_MUXA_NEG_INPUT?has_content>

    /* MUX A Negative Input Select */
    PLIB_ADC_MuxChannel0InputNegativeSelect(DRV_ADC_ID_1, ADC_MUX_A, ${CONFIG_DRV_ADC_MUXA_NEG_INPUT});
</#if>
<#if CONFIG_DRV_ADC_MUXB_NEG_INPUT?has_content>

    /* MUX B Negative Input Select */
    PLIB_ADC_MuxChannel0InputNegativeSelect(DRV_ADC_ID_1, ADC_MUX_B, ${CONFIG_DRV_ADC_MUXB_NEG_INPUT});
</#if>
</#if>
<#macro ADC_CHANNEL_SCAN_FUNCTION SCAN_INST SCAN_ENABLE SCAN_CHN_NUM ESCAN_ENABLE ESCAN_CHN_NUM
MUX_SEL_A MUX_SEL_B DEDICATED_CHN_NUM>
<#if CONFIG_DRV_ADC_SCAN_MODE == true>
<#if SCAN_ENABLE == false>
<#if ESCAN_ENABLE == false>
<#if CONFIG_DRV_ADC_ALTS_MODE == "ADC_SAMPLING_MODE_MUXA">

    /* MUX A Positive Input Select */
    PLIB_ADC_MuxChannel0InputPositiveSelect(DRV_ADC_ID_1, ADC_MUX_A, ${DEDICATED_CHN_NUM});
<#else>
<#if MUX_SEL_A == true>

    /* MUX A Positive Input Select */
    PLIB_ADC_MuxChannel0InputPositiveSelect(DRV_ADC_ID_1, ADC_MUX_A, ${DEDICATED_CHN_NUM});
</#if>
<#if MUX_SEL_B == true>

    /* MUX B Positive Input Select */
    PLIB_ADC_MuxChannel0InputPositiveSelect(DRV_ADC_ID_1, ADC_MUX_B, ${DEDICATED_CHN_NUM});
</#if>
</#if>
<#else> <#--ESCAN_ENABLE == false-->

    /* Select Extended Scan Input ${SCAN_INST} */
    PLIB_ADC_InputScanMaskAddExtended(DRV_ADC_ID_1, ${ESCAN_CHN_NUM});
</#if> <#--ESCAN_ENABLE == false-->
<#else> <#--SCAN_ENABLE == false-->
    /* Select Scan Input ${SCAN_INST} */
    PLIB_ADC_InputScanMaskAdd(DRV_ADC_ID_1, ${SCAN_CHN_NUM});
</#if> <#--SCAN_ENABLE == false-->
<#else> <#--CONFIG_DRV_ADC_SCAN_MODE == true-->
<#if CONFIG_DRV_ADC_ALTS_MODE == "ADC_SAMPLING_MODE_MUXA">

    /* MUX A Positive Input Select */
    PLIB_ADC_MuxChannel0InputPositiveSelect(DRV_ADC_ID_1, ADC_MUX_A, ${DEDICATED_CHN_NUM});
<#else>
<#if MUX_SEL_A == true>

    /* MUX A Positive Input Select */
    PLIB_ADC_MuxChannel0InputPositiveSelect(DRV_ADC_ID_1, ADC_MUX_A, ${DEDICATED_CHN_NUM});
</#if>
<#if MUX_SEL_B == true>

    /* MUX B Positive Input Select */
    PLIB_ADC_MuxChannel0InputPositiveSelect(DRV_ADC_ID_1, ADC_MUX_B, ${DEDICATED_CHN_NUM});
</#if>
</#if> <#--CONFIG_DRV_ADC_SCAN_MODE == true-->
</#if>
</#macro>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX0 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="0" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX0
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX0 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX0
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX0 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX0
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX0 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX0/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX1 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="1" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX1
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX1 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX1
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX1 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX1
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX1 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX1/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX2 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="2" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX2 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX2 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX2
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX2 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX2
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX2 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX2/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX3 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="3" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX3 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX3 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX3
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX3 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX3
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX3 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX3/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX4 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="4" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX4
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX4 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX4
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX4 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX4
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX4 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX4/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX5 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="5" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX5
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX5 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX5
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX5 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX5
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX5 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX5/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX6 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="6" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX6 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX6 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX6
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX6 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX6
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX6 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX6/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX7 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="7" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX7 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX7 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX7
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX7 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX7
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX7 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX7/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX8 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="8" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX8 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX8 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX8
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX8 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX8
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX8 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX8/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX9 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="9" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX9
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX9 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX9
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX9 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX9
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX9 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX9/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX10 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="10" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX10 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX10 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX10
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX10 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX10
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX10 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX10/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX11 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="11" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX11 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX11 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX11
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX11 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX11
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX11 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX11/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX12 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="12" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX12 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX12 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX12
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX12 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX12
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX12 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX12/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX13 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="13" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX13 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX13 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX13
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX13 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX13
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX13 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX13/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX14 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="14" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX14 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX14 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX14
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX14 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX14
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX14 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX14/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX15 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="15" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX15 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX15 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX15
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX15 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX15
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX15 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX15/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX16 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="16" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX16 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX16 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX16
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX16 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX16
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX16 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX16/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX17 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="18" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX17 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX17 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX17
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX17 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX17
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX17 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX17/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX18 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="19" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX19 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX18 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX18
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX18 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX18
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX18 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX18/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX19 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="20" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX20
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX19 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX19
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX19 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX19
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX19 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX19/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX20 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="20" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX20 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX20 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX20
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX20 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX20
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX20 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX20/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX21 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="21" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX21 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX21 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX21
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX21 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX21
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX21 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX21/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX22 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="22" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX22 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX22 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX22
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX22 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX22
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX22 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX22/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX23 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="23" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX23 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX23 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX23
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX23 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX23
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX23 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX23/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX24 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="24" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX24 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX24 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX24
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX24 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX24
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX24 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX24/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX25 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="25" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX25 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX25 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX25
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX25 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX25
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX25 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX25/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX26 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="26" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX26 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX26 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX26
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX26 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX26
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX26 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX26/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX27 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="27" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX27 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX27 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX27
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX27 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX27
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX27 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX27/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX28 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="28" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX28 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX28 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX28
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX28 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX28
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX28 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX28/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX29 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="29" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX29 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX29 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX29
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX29 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX29
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX29 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX29/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX30 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="30" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX30
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX30 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX30
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX30 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX30
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX30 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX30/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX31 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="31" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX31
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX31 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX31
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX31 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX31
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX31 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX31/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX32 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="32" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX32
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX32 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX32
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX32 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX32
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX32 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX32/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX33 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="33" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX33
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX33 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX33
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX33 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX33
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX33 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX33/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX34 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="34" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX34 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX34 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX34
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX34 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX34
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX34 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX34/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX35 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="35" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX35 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX35 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX35
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX35 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX35
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX35 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX35/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX36 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="36" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX36 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX36 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX36
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX36 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX36
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX36 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX36/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX37 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="37" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX37 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX37 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX37
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX37 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX37
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX37 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX37/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX38 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="38" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX38 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX38 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX38
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX38 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX38
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX38 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX38/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX39 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="39" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX39 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX39 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX39
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX39 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX39
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX39 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX39/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX40 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="40" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX40 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX40 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX40
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX40 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX40
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX40 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX40/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX41 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="41" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX41 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX41 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX41
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX41 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX41
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX41 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX41/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX42 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="42" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX42 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX42 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX42
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX42 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX42
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX42 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX42/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX43 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="43" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX43 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX43 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX43
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX43 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX43
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX43 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX43/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX44 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="44" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX44 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX44 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX44
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX44 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX44
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX44 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX44/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX45 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="45" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX45 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX45 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX45
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX45 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX45
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX45 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX45/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX46 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="46" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX46 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX46 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX46
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX46 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX46
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX46 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX46/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX47 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="47" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX47 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX47 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX47
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX47 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX47
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX47 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX47/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX49 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="48" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX48 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX48 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX48
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX48 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX48
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX48 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX48/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX49 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="49" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX49 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX49 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX49
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX49 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX49
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX49 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX49/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX50 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="50" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX50 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX50 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX50
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX50 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX50
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX50 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX50/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX51 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="51" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX51 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX51 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX51
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX51 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX51
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX51 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX51/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX52 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="52" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX52 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX52 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX52
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX52 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX52
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX52 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX52/>
</#if>
<#if CONFIG_DRV_ADC_CHANNEL_INST_IDX53 == true>
<@ADC_CHANNEL_SCAN_FUNCTION SCAN_INST="53" SCAN_ENABLE=CONFIG_DRV_ADC_TYPE_SCAN_IDX53 
SCAN_CHN_NUM=CONFIG_DRV_ADC_SCAN_CHANNEL_NUMBER_IDX53 ESCAN_ENABLE=CONFIG_DRV_ADC_TYPE_ESCAN_IDX53
ESCAN_CHN_NUM=CONFIG_DRV_ADC_ESCAN_CHANNEL_NUMBER_IDX53 MUX_SEL_A=CONFIG_DRV_ADC_SEL_MUXA_IDX53
MUX_SEL_B=CONFIG_DRV_ADC_SEL_MUXB_IDX53 DEDICATED_CHN_NUM=CONFIG_DRV_ADC_POSITIVE_CHANNEL_NUMBER_IDX53/>
</#if>
<#if CONFIG_DRV_ADC_INTERRUPT_MODE == true>
    /* Initialize ADC Interrupt */
    PLIB_INT_SourceFlagClear(INT_ID_0, ${CONFIG_DRV_ADC_INTERRUPT_SOURCE});
    PLIB_INT_SourceEnable(INT_ID_0, ${CONFIG_DRV_ADC_INTERRUPT_SOURCE});
    PLIB_INT_VectorPrioritySet(INT_ID_0, ${CONFIG_DRV_ADC_INTERRUPT_VECTOR}, ${CONFIG_DRV_ADC_INTERRUPT_PRIORITY});
    PLIB_INT_VectorSubPrioritySet(INT_ID_0, ${CONFIG_DRV_ADC_INTERRUPT_VECTOR}, ${CONFIG_DRV_ADC_INTERRUPT_SUB_PRIORITY});	
</#if>
}

inline void DRV_ADC_DeInitialize(void)
{
    /* Disable ADC */
    PLIB_ADC_Disable(DRV_ADC_ID_1);
}

inline void DRV_ADC_Open(void)
{
    /* Enable ADC */
    PLIB_ADC_Enable(DRV_ADC_ID_1);
}

inline void DRV_ADC_Close(void)
{
    /* Disable ADC */
    PLIB_ADC_Disable(DRV_ADC_ID_1);
}

inline void DRV_ADC_Start(void)
{
    /* Start ADC */
    PLIB_ADC_SamplingStart(DRV_ADC_ID_1);
}

inline void DRV_ADC_Stop(void)
{
    /* Stop ADC */
    PLIB_ADC_SamplingStop(DRV_ADC_ID_1);	
}

inline void DRV_ADC_NegativeInputSelect(DRV_ADC_MUX mux, DRV_ADC_INPUTS_NEGATIVE input)
{
    /* Select Negative Input */
    PLIB_ADC_MuxChannel0InputNegativeSelect(DRV_ADC_ID_1, mux, input);
}

inline void DRV_ADC_PositiveInputSelect(DRV_ADC_MUX mux, DRV_ADC_INPUTS_POSITIVE input)
{
    /* Select Positive Input */
    PLIB_ADC_MuxChannel0InputPositiveSelect(DRV_ADC_ID_1, mux, input);
}

inline void DRV_ADC_ChannelScanInputsAdd(DRV_ADC_INPUTS_SCAN scanInput)
{
    /* Add Scan Input */
    PLIB_ADC_InputScanMaskAdd(DRV_ADC_ID_1, scanInput);
}

inline void DRV_ADC_ChannelScanInputsRemove(DRV_ADC_INPUTS_SCAN scanInput)
{
    /* Remove Scan Input */
    PLIB_ADC_InputScanMaskRemove(DRV_ADC_ID_1, scanInput);
}

<#if CONFIG_HAVE_ADC_ESCAN == true>

inline void DRV_ADC_ChannelExtendedScanInputsAdd(DRV_ADC_INPUTS_SCAN_EXTENDED eScanInput)
{
    /* Add Scan Input */
    PLIB_ADC_InputScanMaskAddExtended(DRV_ADC_ID_1, eScanInput);
}

inline void DRV_ADC_ChannelExtendedScanInputsRemove(DRV_ADC_INPUTS_SCAN_EXTENDED eScanInput)
{
    /* Remove Scan Input */
    PLIB_ADC_InputScanMaskRemoveExtended(DRV_ADC_ID_1, eScanInput);
}
</#if>
ADC_SAMPLE DRV_ADC_SamplesRead(uint8_t bufIndex)
{
    /* Read Result */
    return PLIB_ADC_ResultGetByIndex(DRV_ADC_ID_1, bufIndex);
}

bool DRV_ADC_SamplesAvailable(void)
{
    /* Wait for DONE Flag */
    while (!PLIB_ADC_ConversionHasCompleted(DRV_ADC_ID_1));
	
    return true;
}
</#if>
</#if>
<#--
/*******************************************************************************
 End of File
*/
-->
