/*******************************************************************************
  WiFi MAC interface functions

  File Name:
    wdrv_mrf24wn_priv.h

  Summary:
   WiFi-specific MAC function prototypes called by TCP/IP stack.

  Description:
    The functions in this header file are accessed by the TCP/IP stack via
    function pointers.
*******************************************************************************/

// DOM-IGNORE-BEGIN
/*******************************************************************************
Copyright ?2012 released Microchip Technology Inc. All rights reserved.

Microchip licenses to you the right to use, modify, copy and distribute
Software only when embedded on a Microchip microcontroller or digital signal
controller that is integrated into your product or third party product
(pursuant to the sublicense terms in the accompanying license agreement).

You should refer to the license agreement accompanying this Software for
additional information regarding your rights and obligations.

SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND,
EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER
CONTRACT, NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR
OTHER LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR
CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF
SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
(INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.
*******************************************************************************/

#ifndef _WDRV_MRF24WN_PRIV_H
#define _WDRV_MRF24WN_PRIV_H

#include "tcpip/src/tcpip_private.h"

typedef struct
{
    uint8_t trafficEvents;
    uint16_t trafficEventInfo;
} WDRV_MRF24WN_USREV_DCPT;

// stack internal notification
typedef struct
{
    bool                     mrfEnabledEvents; // group enabled notification events
    volatile TCPIP_MAC_EVENT mrfPendingEvents; // group notification events that are set, waiting to be re-acknowledged
    TCPIP_MAC_EventF         mrfNotifyFnc; // group notification handler
    const void              *mrfNotifyParam; // notification parameter
} WDRV_MRF24WN_EVGROUP_DCPT; // event descriptor

typedef struct {
    volatile uint32_t initDriverDone;
    volatile uint32_t deinitDriverDone;
    volatile uint32_t updateMacAddressRequired;
    uint8_t macAddr[6];
    OSAL_MUTEX_HANDLE_TYPE *debugConsoleLock;
    OSAL_MUTEX_HANDLE_TYPE *multicastFilterLock;
    volatile bool isScanDone;
    bool initConn;
    volatile bool isConnReestablished;
    bool isDisconnectRequested;
    OSAL_SEM_HANDLE_TYPE disconnectDoneSync;
    OSAL_SEM_HANDLE_TYPE dmaTxSync;
    OSAL_SEM_HANDLE_TYPE dmaRxSync;
} WDRV_MRF24WN_PRIV;

typedef struct {
   void (*CopyFrameToStackPacketBuffer_CB)(uint32_t len, uint8_t const * const frame);
   void (*ProceedConnectEvent_CB)(int connected, uint8_t devID, uint8_t *bssid, bool bssConn, uint8_t reason);
   void (*RFReady_CB)(uint8_t const * const addr);
   void (*ScanDone_CB)(int32_t status);
   void (*InitDone_CB)(void);
   void (*DeinitDone_CB)(void);
   void (*WPSDone_CB)(void);
   uint8_t address[6];
   uint32_t versions[2];
} WDRV_MRF24WN_UPPER_CTX;

typedef enum 
{  
    WDRV_ERROR                = -1,
    WDRV_SUCCESS              = 0,
    WDRV_INVALID_TASK_ID      = 1,
    WDRV_INVALID_PARAMETER    = 2,
    WDRV_INVALID_POINTER      = 3,
    WDRV_ALREADY_EXISTS       = 4,
    WDRV_INVALID_EVENT        = 5,
    WDRV_EVENT_TIMEOUT        = 6,
    WDRV_INVALID_MUTEX        = 7,
    WDRV_TASK_ALREADY_LOCKED  = 8,
    WDRV_MUTEX_ALREADY_LOCKED = 9,  
    WDRV_OUT_OF_MEMORY        = 10,
} WDRV_STATUS;

bool WDRV_SemInit(OSAL_SEM_HANDLE_TYPE *SemID);
void WDRV_SemTake(OSAL_SEM_HANDLE_TYPE *SemID, uint16_t timeout);
void WDRV_SemGive(OSAL_SEM_HANDLE_TYPE *SemID);
void WDRV_SemGiveFromISR(OSAL_SEM_HANDLE_TYPE *SemID);
void WDRV_SemDeInit(OSAL_SEM_HANDLE_TYPE *SemID);
uint32_t WDRV_MutexInit(OSAL_MUTEX_HANDLE_TYPE **mutex_ptr);
uint32_t WDRV_MutexDestroy(OSAL_MUTEX_HANDLE_TYPE **mutex_ptr);
uint32_t WDRV_MutexLock(OSAL_MUTEX_HANDLE_TYPE *mutex_ptr, uint32_t tick_count);
uint32_t WDRV_MutexUnlock(OSAL_MUTEX_HANDLE_TYPE *mutex_ptr);
WDRV_STATUS WDRV_TaskCreate(void Task(void *), char *task_name, int stack_size, void *param, 
    unsigned long task_priority, TaskHandle_t *task_handle, bool auto_start);
WDRV_STATUS WDRV_TaskDestroy(TaskHandle_t task_handle);
void WDRV_UsecDelay(uint32_t uSec);

void WDRV_PendingEventProcess(void);
bool isEventPended(void);

void WDRV_GPIO_OutLow_PIC32MZ_ESK(uint32_t channel, uint32_t bit_pos);
void WDRV_GPIO_OutLow_PIC32MX_ESK(uint32_t channel, uint32_t bit_pos);
void WDRV_GPIO_OutLow_PIC32MX_EXP16(uint32_t channel, uint32_t bit_pos);
void WDRV_GPIO_OutLow_PIC32MZ_MEB2(uint32_t channel, uint32_t bit_pos);
void WDRV_GPIO_OutLow_Custom_Board(uint32_t channel, uint32_t bit_pos);
void WDRV_GPIO_OutHigh_PIC32MZ_ESK(uint32_t channel, uint32_t bit_pos);
void WDRV_GPIO_OutHigh_PIC32MX_ESK(uint32_t channel, uint32_t bit_pos);
void WDRV_GPIO_OutHigh_PIC32MX_EXP16(uint32_t channel, uint32_t bit_pos);
void WDRV_GPIO_OutHigh_PIC32MZ_MEB2(uint32_t channel, uint32_t bit_pos);
void WDRV_GPIO_OutHigh_Custom_Board(uint32_t channel, uint32_t bit_pos);

TCPIP_MAC_RES WDRV_MRF24WN_MulticastFilterSet(TCPIP_MAC_HANDLE hMac, TCPIP_MAC_ADDR *DestMACAddr);

void WDRV_DataCacheClean(unsigned char* address, uint32_t size);

extern WDRV_MRF24WN_PRIV g_wdrv_priv;
#endif /*_WDRV_MRF24WN_PRIV_H */

// DOM-IGNORE-END
